/*
** Module   : ResourceEvent.java
** Abstract : defines an event which originates from the server-side, via a APPLY ... TO <handle> 
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130813 Created initial version.
*/

package com.goldencode.p2j.ui.client.event;

import com.goldencode.p2j.ui.client.widget.*;

/**
 * Instances of this class represent a definition of an event which originates from the server 
 * side and was raised via a APPLY ... TO handle call, where the handle points to a non-widget
 * resource.
 */
public class ResourceEvent
extends Event
{
   /** The resource ID. */
   private long resId;

   /**
    * Constructor.
    * 
    * @param   source
    *          The active widget for this event.
    * @param   resId
    *          The event's resource ID.
    * @param   id
    *          Event type ID.
    */
   public ResourceEvent(Widget source, long resId, int id)
   {
      super(source, id);
      
      this.resId = resId;
   }

   /**
    * Get the associated resource ID.
    * 
    * @return   The {@link #resourceId()}.
    */
   public long resourceId()
   {
      return resId;
   }
}
